@@ -27,7 +27,7 @@ def register_views(injector, app):
     from iatoolkit.views.tasks_review_view import TaskReviewView
     from iatoolkit.views.home_view import HomeView
     from iatoolkit.views.login_view import LoginView, InitiateLoginView
-    from iatoolkit.views.login_external_id_view import InitiateExternalChatView, ExternalChatLoginView
+    from iatoolkit.views.external_login_view import InitiateExternalChatView, ExternalChatLoginView
     from iatoolkit.views.signup_view import SignupView
     from iatoolkit.views.verify_user_view import VerifyAccountView
     from iatoolkit.views.forgot_password_view import ForgotPasswordView
@@ -73,7 +73,7 @@ def register_views(injector, app):
         view_func=lambda: render_template('about.html'))
 
     app.add_url_rule('/version', 'version',
-                     lambda: jsonify({"version": app.config['VERSION']}))
+                     lambda: jsonify({"iatoolkit_version": current_app.config.get('VERSION', 'N/A')}))
 
     app.add_url_rule('/<company_short_name>/<external_user_id>/download-file/<path:filename>',
                      view_func=DownloadFileView.as_view('download-file'))
