@@ -15,6 +15,8 @@ import logging
 import os
 from typing import Optional, Dict, Any
 from iatoolkit.repositories.database_manager import DatabaseManager
+from werkzeug.middleware.proxy_fix import ProxyFix
+
 
 from injector import Binder, singleton, Injector
 from importlib.metadata import version as _pkg_version, PackageNotFoundError
@@ -100,10 +102,7 @@ class IAToolkit:
         # Step 8: define the download_dir for excel's
         self._setup_download_dir()
 
-        try:
-            self.version = _pkg_version("iatoolkit")
-        except PackageNotFoundError:
-            pass
+
 
         logging.info(f"🎉 IAToolkit v{self.version} inicializado correctamente")
         self._initialized = True
@@ -114,8 +113,9 @@ class IAToolkit:
         return self.config.get(key, os.getenv(key, default))
 
     def _setup_logging(self):
-        log_level_str = self._get_config_value('FLASK_ENV', 'production')
-        log_level = logging.INFO if log_level_str in ('dev', 'development') else logging.WARNING
+        # Lee el nivel de log desde una variable de entorno, con 'INFO' como valor por defecto.
+        log_level_name = os.getenv('LOG_LEVEL', 'INFO').upper()
+        log_level = getattr(logging, log_level_name, logging.INFO)
 
         logging.basicConfig(
             level=log_level,
@@ -148,6 +148,13 @@ class IAToolkit:
         parsed_url = urlparse(os.getenv('IATOOLKIT_BASE_URL'))
         domain = parsed_url.netloc
 
+        try:
+            self.version = _pkg_version("iatoolkit")
+        except PackageNotFoundError:
+            pass
+
+        self.app.wsgi_app = ProxyFix(self.app.wsgi_app, x_proto=1)
+
         self.app.config.update({
             'VERSION': self.version,
             'SERVER_NAME': domain,
