@@ -6,14 +6,13 @@
 from flask.views import MethodView
 from flask import request, redirect, render_template, url_for
 from injector import inject
-from iatoolkit.repositories.models import User
 from iatoolkit.services.profile_service import ProfileService
 from iatoolkit.services.prompt_manager_service import PromptService
-from iatoolkit.services.branding_service import BrandingService
 from iatoolkit.services.query_service import QueryService
 import os
 from iatoolkit.common.session_manager import SessionManager
 from iatoolkit.services.branding_service import BrandingService
+from iatoolkit.services.onboarding_service import OnboardingService
 
 class InitiateLoginView(MethodView):
     """
@@ -24,9 +23,11 @@ class InitiateLoginView(MethodView):
     @inject
     def __init__(self,
                  profile_service: ProfileService,
-                 branding_service: BrandingService,):
+                 branding_service: BrandingService,
+                 onboarding_service: OnboardingService):
         self.profile_service = profile_service
         self.branding_service = branding_service
+        self.onboarding_service = onboarding_service
 
     def post(self, company_short_name: str):
         # get company info
@@ -56,18 +57,22 @@ class InitiateLoginView(MethodView):
                 },
                 alert_message=response["error"]), 400
 
-        # 2. Get branding data for the shell page
+        # 2. Get branding and onboarding data for the shell page
         branding_data = self.branding_service.get_company_branding(company)
+        onboarding_cards = self.onboarding_service.get_onboarding_cards(company)
+
+        target_url = url_for('login',
+                        company_short_name=company_short_name,
+                        _external=True)
 
         # 3. Render the shell page, passing the URL for the heavy lifting
         # The shell's AJAX call will now be authenticated via the session cookie.
         return render_template(
-            "login_shell.html",
-            data_source_url=url_for('login',
-                        company_short_name=company_short_name,
-                        _external=True),
+            "onboarding_shell.html",
+            iframe_src_url=target_url,
             external_user_id='',
             branding=branding_data,
+            onboarding_cards=onboarding_cards
         )
 
 
@@ -84,52 +89,48 @@ class LoginView(MethodView):
         self.branding_service = branding_service
 
     def get(self, company_short_name: str):
-        # get company info
+        """
+        Handles the heavy-lifting part of the login, triggered by the iframe.
+        The user is already authenticated via the session cookie.
+        """
+        # 1. Retrieve user and company info from the session.
+        user_id = SessionManager.get('user_id')
+        if not user_id:
+            # This can happen if the session expires or is invalid.
+            # Redirecting to home is a safe fallback.
+            return redirect(url_for('home', company_short_name=company_short_name))
+
+        user_email = SessionManager.get('user')['email']
         company = self.profile_service.get_company_by_short_name(company_short_name)
         if not company:
             return render_template('error.html', message="Empresa no encontrada"), 404
 
-        return render_template('login.html',
-                               company=company,
-                               company_short_name=company_short_name)
-
-    def post(self, company_short_name: str):
-        company = self.profile_service.get_company_by_short_name(company_short_name)
-
-        # 1. The user is already authenticated by the session cookie set by InitiateLoginView.
-        # We just retrieve the user and company IDs from the session.
-        user_id = SessionManager.get('user_id')
-        if not user_id:
-            return render_template('error.html', message="Usuario no encontrado"), 404
-
-        user_email = SessionManager.get('user')['email']
-
         try:
-            # 2. init the company/user LLM context.
+            # 2. Init the company/user LLM context (the long-running task).
             self.query_service.llm_init_context(
                 company_short_name=company_short_name,
                 local_user_id=user_id
             )
 
-            # 3. get the prompt list from backend
+            # 3. Get the prompt list from backend.
             prompts = self.prompt_service.get_user_prompts(company_short_name)
 
-            # 4. get the branding data
+            # 4. Get the branding data.
             branding_data = self.branding_service.get_company_branding(company)
 
+            # 5. Render the final chat page.
             return render_template("chat.html",
-                                    company_short_name=company_short_name,
-                                    auth_method="Session",
-                                    session_jwt=None,  # No JWT in this flow
-                                    user_email=user_email,
-                                    branding=branding_data,
-                                    prompts=prompts,
-                                    iatoolkit_base_url=os.getenv('IATOOLKIT_BASE_URL'),
-                                    ), 200
+                                   company_short_name=company_short_name,
+                                   auth_method="Session",
+                                   session_jwt=None,  # No JWT in this flow
+                                   user_email=user_email,
+                                   branding=branding_data,
+                                   prompts=prompts,
+                                   iatoolkit_base_url=os.getenv('IATOOLKIT_BASE_URL'),
+                                   ), 200
 
         except Exception as e:
             return render_template("error.html",
                                    company=company,
                                    company_short_name=company_short_name,
-                                   message="Ha ocurrido un error inesperado."), 500
-
+                                   message="Ha ocurrido un error inesperado."), 500
\ No newline at end of file
